﻿using System.ComponentModel;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace Altairis.Web.Icons {
    public class IconHyperLink : CompositeControl {
        private const string ResourceNameFormat = "Altairis.Web.Icons.Resources.{0}.png";

        public IconHyperLink() {
            this.Icon = IconType.NoIcon;
            this.Mode = DisplayMode.IconLeft;
        }

        [Category("Navigation"), DefaultValue(""), Bindable(true), UrlProperty]
        public string NavigateUrl {
            get { return (string)(this.ViewState["NavigateUrl"] ?? string.Empty); }
            set { this.ViewState["NavigateUrl"] = value; }
        }

        [Category("Navigation"), DefaultValue(""), TypeConverter(typeof(TargetConverter))]
        public string Target {
            get { return (string)(this.ViewState["Target"] ?? string.Empty); }
            set { this.ViewState["Target"] = value; }
        }

        [Category("Appearance"), DefaultValue(""), Bindable(true), Localizable(true)]
        public string Text {
            get { return (string)(this.ViewState["Text"] ?? string.Empty); }
            set { this.ViewState["Text"] = value; }
        }

        [Category("Appearance"), Themeable(true), Bindable(true), DefaultValue(IconType.NoIcon)]
        public IconType Icon {
            get { return (IconType)(this.ViewState["Icon"] ?? IconType.NoIcon); }
            set { this.ViewState["Icon"] = value; }
        }

        [Category("Appearance"), Themeable(true), DefaultValue(DisplayMode.IconLeft)]
        public DisplayMode Mode {
            get { return (DisplayMode)(this.ViewState["Mode"] ?? DisplayMode.IconLeft); }
            set { this.ViewState["Mode"] = value; }
        }

        protected override void CreateChildControls() {
            switch (this.Mode) {
                case DisplayMode.IconLeft:
                    this.AddIconLink();
                    this.AddTextLink();
                    break;
                case DisplayMode.IconRight:
                    this.AddTextLink();
                    this.AddIconLink();
                    break;
                case DisplayMode.IconOnly:
                    this.AddIconLink();
                    break;
                default: // DisplayMode.TextOnly:
                    this.AddTextLink();
                    break;
            }
        }

        private void AddIconLink() {
            // If no icon specified, do nothing
            if (this.Icon == IconType.NoIcon) return;

            // Create new hyperlink and setup basic properties
            HyperLink link = new HyperLink();
            link.NavigateUrl = this.NavigateUrl;
            link.Text = this.Text;
            link.Target = this.Target;
            link.Width = Unit.Pixel(16);
            link.Height = Unit.Pixel(16);
            link.ToolTip = this.ToolTip;

            // Set image source to web resource to this item
            link.ImageUrl = this.Page.ClientScript.GetWebResourceUrl(
                this.GetType(),
                string.Format(ResourceNameFormat, this.Icon));

            // Add to child controls
            this.Controls.Add(link);
        }

        private void AddTextLink() {
            // If no text specified, do nothing
            if (string.IsNullOrEmpty(this.Text)) return;

            // Create new hyperlink and setup basic properties
            HyperLink link = new HyperLink();
            link.NavigateUrl = this.NavigateUrl;
            link.Text = this.Text;
            link.Target = this.Target;

            // Add to child controls
            this.Controls.Add(link);
        }

    }
}
